@@ -2,9 +2,15 @@ from typing import *
 
 
 class CClass:
-    def __getitem__(self, _0: Union[numpy.ndarray, Tuple[numpy.ndarray, ...]], /):
+    def __getitem__(
+        self,
+        _0: Union[numpy.ndarray, Tuple[Union[numpy.ndarray, List[complex]], ...]],
+        /,
+    ):
         """
+        usage.matplotlib: 1
         usage.pandas: 3
+        usage.scipy: 23
         usage.skimage: 1
         usage.sklearn: 40
         """
@@ -15,12 +21,15 @@ class IndexExpression:
     def __getitem__(
         self,
         _0: Union[
-            slice[None, None, None], Tuple[slice[int, int, int], slice[int, int, int]]
+            slice[Union[None, int], Union[None, int], Union[None, int]],
+            Tuple[slice[int, int, int], slice[int, int, int]],
         ],
         /,
     ):
         """
+        usage.matplotlib: 2
         usage.pandas: 2
+        usage.scipy: 21
         usage.skimage: 1
         usage.sklearn: 2
         """
@@ -33,23 +42,26 @@ class MGridClass:
         _0: Union[
             Tuple[
                 slice[
-                    Union[None, numpy.float64, int],
-                    Union[int, numpy.float64],
-                    Union[None, numpy.float64, int],
+                    Union[None, numpy.float64, int, float],
+                    Union[int, numpy.float64, float],
+                    Union[None, numpy.float64, int, float],
                 ],
                 ...,
             ],
             List[
                 slice[
-                    Union[numpy.int64, None],
-                    Union[numpy.int64, int],
-                    Union[numpy.int64, None],
+                    Union[int, numpy.int64, None],
+                    Union[int, numpy.int64],
+                    Union[int, numpy.int64, None],
                 ]
             ],
+            slice[int, int, int],
         ],
         /,
     ):
         """
+        usage.matplotlib: 12
+        usage.scipy: 6
         usage.skimage: 57
         usage.sklearn: 1
         """
@@ -59,10 +71,16 @@ class MGridClass:
 class OGridClass:
     def __getitem__(
         self,
-        _0: Tuple[slice[Union[None, int], Union[int, float], Union[None, int]], ...],
+        _0: Union[
+            Tuple[slice[Union[None, int], Union[int, float], Union[None, int]], ...],
+            List[slice[int, int, int]],
+        ],
         /,
     ):
         """
+        usage.dask: 2
+        usage.matplotlib: 4
+        usage.scipy: 4
         usage.skimage: 8
         """
         ...
@@ -72,15 +90,22 @@ class RClass:
     def __getitem__(
         self,
         _0: Union[
+            List[Union[List[Union[int, float]], numpy.ndarray, int]],
             tuple,
-            slice[Union[int, None], int, Union[int, None]],
+            int,
             numpy.ndarray,
-            List[Union[int, List[Union[int, float]]]],
+            slice[
+                Union[int, numpy.int64, None],
+                Union[int, numpy.int64],
+                Union[int, numpy.int64, None],
+            ],
         ],
         /,
     ):
         """
+        usage.matplotlib: 6
         usage.pandas: 13
+        usage.scipy: 187
         usage.skimage: 16
         usage.sklearn: 37
         usage.xarray: 3
