@@ -3,6 +3,11 @@ from typing import *
 # usage.sklearn: 1
 arraysetops: object
 
+# usage.dask: 1
+mixins: object
+
+# usage.matplotlib: 2
 # usage.pandas: 2
+# usage.scipy: 2
 # usage.xarray: 1
 stride_tricks: object
