@@ -2,9 +2,7 @@ from typing import *
 
 
 class OutOfBoundsDatetime:
-    def __init__(
-        self, _0: Literal["Cannot decode times from a non-standard calendar, "], /
-    ):
+    def __init__(self, _0: str, /):
         """
         usage.xarray: 1
         """
