@@ -10,13 +10,13 @@ class IndexOpsMixin:
 
     def max(self, /):
         """
-        usage.dask: 14
+        usage.dask: 18
         """
         ...
 
     def min(self, /):
         """
-        usage.dask: 14
+        usage.dask: 18
         """
         ...
 
@@ -34,12 +34,13 @@ class IndexOpsMixin:
 
     def to_numpy(self, /):
         """
-        usage.xarray: 2
+        usage.xarray: 3
         """
         ...
 
     def tolist(self, /):
         """
         usage.dask: 14
+        usage.sklearn: 1
         """
         ...
