@@ -15,6 +15,12 @@ class DatetimeIndexOpsMixin:
         """
         ...
 
+    def isin(self, /, values: pandas.core.indexes.datetimes.DatetimeIndex):
+        """
+        usage.dask: 1
+        """
+        ...
+
     def max(self, /):
         """
         usage.dask: 9
@@ -33,6 +39,12 @@ class DatetimeIndexOpsMixin:
         """
         ...
 
+    def sort_values(self, /):
+        """
+        usage.xarray: 1
+        """
+        ...
+
     def take(self, /, indices: numpy.ndarray):
         """
         usage.xarray: 1
