@@ -15,8 +15,9 @@ class IndexingError:
 class _LocIndexer:
     def __getitem__(self, _0: object, /):
         """
-        usage.xarray: 3
-        usage.dask: 257
+        usage.dask: 263
+        usage.sklearn: 30
+        usage.xarray: 45
         """
         ...
 
@@ -25,32 +26,51 @@ class _iLocIndexer:
     def __getitem__(
         self,
         _0: Union[
-            Tuple[
-                slice[Union[None, int], Union[None, int], Union[None, int]],
-                Union[int, List[Union[bool, int]]],
+            slice[
+                Union[numpy.int64, int, None],
+                Union[None, numpy.int64, int],
+                Union[numpy.int64, int, None],
             ],
+            Tuple[
+                Union[
+                    slice[Union[None, int], Union[None, int], Union[None, int]],
+                    numpy.ndarray,
+                    int,
+                ],
+                Union[
+                    List[Union[int, bool]],
+                    int,
+                    numpy.ndarray,
+                    slice[Union[int, None], Union[int, None], Union[int, None]],
+                ],
+            ],
+            List[int],
             numpy.ndarray,
             int,
-            slice[
-                Union[int, numpy.int64, None],
-                Union[numpy.int64, int, None],
-                Union[int, numpy.int64, None],
-            ],
         ],
         /,
     ):
         """
-        usage.dask: 68
+        usage.dask: 72
+        usage.sklearn: 24
+        usage.xarray: 5
         """
         ...
 
     def __setitem__(
         self,
-        _0: Union[Tuple[Union[List[int], slice[None, int, None], int], int], int],
-        _1: float,
+        _0: Union[
+            Tuple[
+                Union[int, slice[None, Union[None, int], None], List[int]],
+                Union[int, numpy.int32],
+            ],
+            int,
+        ],
+        _1: Union[numpy.float64, pandas.core.series.Series, float],
         /,
     ):
         """
         usage.dask: 5
+        usage.sklearn: 5
         """
         ...
