@@ -28,20 +28,26 @@ class DatetimeIndexResampler:
 
     def count(self, /):
         """
-        usage.dask: 5
+        usage.dask: 7
+        """
+        ...
+
+    def f(self, /):
+        """
+        usage.dask: 3
         """
         ...
 
     def g(self, /):
         """
+        usage.dask: 6
         usage.xarray: 4
-        usage.dask: 5
         """
         ...
 
     def h(self, /):
         """
-        usage.dask: 3
+        usage.dask: 4
         """
         ...
 
@@ -59,20 +65,11 @@ class DatetimeIndexResampler:
 
     def size(self, /):
         """
-        usage.dask: 3
+        usage.dask: 5
         """
         ...
 
 
-class Resampler:
-
-    # usage.dask: 1
-    __module__: ClassVar[object]
-
-    # usage.dask: 1
-    __name__: ClassVar[object]
-
-
 class TimeGrouper:
 
     # usage.dask: 1
