@@ -3,14 +3,15 @@ from typing import *
 
 def concat(
     objs: Union[
-        List[Union[pandas.core.series.Series, pandas.core.frame.DataFrame]],
+        List[Union[pandas.core.frame.DataFrame, pandas.core.series.Series]],
         Dict[int, pandas.core.series.Series],
     ],
     axis: int = ...,
-    join: Literal["inner", "outer"] = ...,
+    join: Literal["outer", "inner"] = ...,
     sort: bool = ...,
 ):
     """
-    usage.dask: 141
+    usage.dask: 149
+    usage.sklearn: 3
     """
     ...
