@@ -10,7 +10,7 @@ def cut(
         range,
     ],
     bins: Union[
-        range, pandas.core.indexes.datetimes.DatetimeIndex, int, List[Union[float, int]]
+        int, range, pandas.core.indexes.datetimes.DatetimeIndex, List[Union[float, int]]
     ],
     right: bool = ...,
     labels: None = ...,
@@ -18,6 +18,6 @@ def cut(
     include_lowest: bool = ...,
 ):
     """
-    usage.xarray: 12
+    usage.xarray: 14
     """
     ...
