@@ -23,9 +23,10 @@ class StringMethods:
         """
         ...
 
-    def contains(self, /, pat: Literal["a", "d"]):
+    def contains(self, /, pat: str):
         """
-        usage.dask: 9
+        usage.dask: 10
+        usage.sklearn: 5
         """
         ...
 
@@ -49,7 +50,7 @@ class StringMethods:
 
     def split(self, /, n: int, expand: bool):
         """
-        usage.dask: 5
+        usage.dask: 8
         """
         ...
 
