@@ -2,11 +2,7 @@ from typing import *
 
 
 def read_json(
-    path_or_buf: Union[
-        _io.TextIOWrapper,
-        _io.StringIO,
-        Literal["/var/folders/xn/05ktz3056kqd9n8frgd6236h0000gn/T/t"],
-    ],
+    path_or_buf: Union[_io.TextIOWrapper, _io.StringIO, str],
     orient: Literal["values", "columns", "index", "records", "split"] = ...,
     lines: bool = ...,
 ):
