@@ -8,7 +8,6 @@ import operator
 import typing
 
 import libcst as cst
-import libcst
 import networkx
 import orjson
 import pydantic
@@ -32,7 +31,24 @@ def bad_name(name: str) -> bool:
 
 
 class BaseModel(pydantic.BaseModel):
-    def __repr_args__(self) -> pydantic.ReprArgs:
+    class Config:
+        extra = "forbid"
+
+    # Set fields set to be all those that are truthy, so only those are expoed with `skip_defaults`
+    @property  # type: ignore
+    def __fields_set__(self) -> typing.Set[str]:  # type: ignore
+        s = set()
+        for k, v in self.__values__.items():
+            if v:
+                s.add(k)
+        return s
+
+    @__fields_set__.setter
+    def __fields_set__(self, val: typing.Set[str]) -> None:
+        pass
+
+    def __repr_args__(self) -> pydantic.ReprArgs:  # type: ignore
+        # Dont show empty valyes
         for k, v in super().__repr_args__():
             if v:
                 yield k, v
@@ -59,16 +75,29 @@ class API(BaseModel):
         return self
 
     def json(self, **kwargs) -> str:
-        return super().json(exclude_none=True, **kwargs)
+        return super().json(exclude_none=True, skip_defaults=True, **kwargs)
 
 
 class Module(BaseModel):
+    function_overloads: typing.Dict[str, typing.List[Signature]] = pydantic.Field(
+        default_factory=dict
+    )
     functions: typing.Dict[str, Signature] = pydantic.Field(default_factory=dict)
     classes: typing.Dict[str, Class] = pydantic.Field(default_factory=dict)
     properties: typing.Dict[str, typing.Tuple[Metadata, Type]] = pydantic.Field(
         default_factory=dict
     )
 
+    @pydantic.root_validator
+    def set_overloads(cls, values):
+        """
+        Set the overloads to be the values, if they are not set
+        """
+        values["function_overloads"] = values.get("function_overloads", {}) or {
+            k: create_overloads(v) for k, v in values["functions"].items()
+        }
+        return values
+
     @property
     def source(self) -> str:
         # try:
@@ -89,10 +118,8 @@ class Module(BaseModel):
         )
         yield from assign_properties(self.properties)
 
-        for name, sig in sort_items(self.functions):
-            if bad_name(name):
-                continue
-            yield sig.function_def(name, "function")
+        yield from function_defs(self.function_overloads, self.functions, "function")
+
         for name, class_ in sort_items(self.classes):
             yield class_.class_def(name)
 
@@ -108,18 +135,37 @@ class Module(BaseModel):
         update_ior(self.functions, other.functions)
         # property -> function
         merge_intersection(self.functions, self.properties, merge_property_into_method)
+        # function overloads
+        update_overloads(self.function_overloads, other.function_overloads)
 
         # classes
         update_ior(self.classes, other.classes)
         # function -> class constructor
         merge_intersection(self.classes, self.functions, merge_method_class)
+        merge_intersection(
+            self.classes, self.function_overloads, merge_method_overloads_class
+        )
 
         return self
 
 
+def create_overloads(s: Signature) -> typing.List[Signature]:
+    """
+    Copies signature to create overloads. Needs to copy because we inplace update the signature later on
+    """
+    return [s.copy(deep=True)]
+
+
 class Class(BaseModel):
+    constructor_overloads: typing.List[Signature] = pydantic.Field(default_factory=list)
     constructor: typing.Union[Signature, None] = None
+    method_overloads: typing.Dict[str, typing.List[Signature]] = pydantic.Field(
+        default_factory=dict
+    )
     methods: typing.Dict[str, Signature] = pydantic.Field(default_factory=dict)
+    classmethod_overloads: typing.Dict[str, typing.List[Signature]] = pydantic.Field(
+        default_factory=dict
+    )
     classmethods: typing.Dict[str, Signature] = pydantic.Field(default_factory=dict)
     properties: typing.Dict[str, typing.Tuple[Metadata, Type]] = pydantic.Field(
         default_factory=dict
@@ -128,26 +174,48 @@ class Class(BaseModel):
         default_factory=dict
     )
 
+    @pydantic.root_validator
+    def set_overloads(cls, values):
+        """
+        Set the overloads to be the values, if not passed in.
+        """
+        if values["constructor"] and not values["constructor_overloads"]:
+            values["constructor_overloads"] = create_overloads(values["constructor"])
+        values["method_overloads"] = values.get("method_overloads", {}) or {
+            k: create_overloads(v) for k, v in values["methods"].items()
+        }
+        values["classmethod_overloads"] = values.get("classmethod_overloads", {}) or {
+            k: create_overloads(v) for k, v in values["classmethods"].items()
+        }
+        return values
+
     def class_def(self, name: str) -> cst.ClassDef:
         return cst.ClassDef(cst.Name(name), cst.IndentedBlock(list(self.body)),)
 
     @property
     def body(self) -> typing.Iterable[cst.BaseStatement]:
         if self.constructor is not None:
-            yield self.constructor.function_def("__init__", "method", indent=1)
+            function_def_with_overloads(
+                "__init__",
+                self.constructor_overloads,
+                self.constructor,
+                "method",
+                indent=1,
+            )
         yield from assign_properties(self.classproperties, True)
 
-        for name, sig in sort_items(self.classmethods):
-            if bad_name(name):
-                continue
-            yield sig.function_def(name, "classmethod", indent=1)
-
+        yield from function_defs(
+            self.classmethod_overloads, self.classmethods, "classmethod", 1
+        )
         yield from assign_properties(self.properties)
 
-        for name, sig in sort_items(self.methods):
-            if bad_name(name):
-                continue
-            yield sig.function_def(name, "method", indent=1)
+        yield from function_defs(self.method_overloads, self.methods, "method", 1)
+
+    def ior_constructor(self, other: typing.Optional[Signature]) -> None:
+        if self.constructor and other:
+            self.constructor |= other
+        else:
+            self.constructor = other
 
     def __ior__(self, other: Class) -> Class:
         """
@@ -160,10 +228,9 @@ class Class(BaseModel):
 
         * (implicit) property -> classmethod 
         """
-        if self.constructor and other.constructor:
-            self.constructor |= other.constructor
-        else:
-            self.constructor = other.constructor
+        self.ior_constructor(other.constructor)
+        merge_overloads(self.constructor_overloads, other.constructor_overloads)
+
         # properties
         update_metadata_and_types(self.properties, other.properties)
 
@@ -178,11 +245,19 @@ class Class(BaseModel):
         update_ior(self.methods, other.methods)
         # property -> method
         merge_intersection(self.methods, self.properties, merge_property_into_method)
+        # method overloads
+        update_overloads(self.method_overloads, other.method_overloads)
 
         # class methods
         update_ior(self.classmethods, other.classmethods)
         # method -> classmethod
         merge_intersection(self.classmethods, self.methods, operator.ior)
+        # classmethod overloads
+        merge_intersection(
+            self.classmethod_overloads, self.method_overloads, merge_overloads
+        )
+        update_overloads(self.classmethod_overloads, other.classmethod_overloads)
+
         # classproperty -> classmethod
         merge_intersection(
             self.classmethods, self.classproperties, merge_property_into_method
@@ -224,7 +299,38 @@ def sort_items(d: typing.Dict[str, V]) -> typing.Iterable[typing.Tuple[str, V]]:
     return sorted(d.items(), key=lambda kv: kv[0])
 
 
-PartialKeyOrdering = typing.Set[typing.Tuple[str, str]]
+PartialKeyOrdering = typing.List[typing.Tuple[str, str]]
+
+
+def function_defs(
+    overloads: typing.Dict[str, typing.List[Signature]],
+    functions: typing.Dict[str, Signature],
+    type: typing.Literal["function", "classmethod", "method"],
+    indent: int = 0,
+) -> typing.Iterable[cst.FunctionDef]:
+    """
+    Exports CST for functions plus overloads
+    """
+    for name, sig in sort_items(functions):
+        if bad_name(name):
+            continue
+        yield from function_def_with_overloads(
+            name, overloads.get(name, []), sig, type, indent
+        )
+
+
+def function_def_with_overloads(
+    name: str,
+    overloads: typing.List[Signature],
+    fn: Signature,
+    type: typing.Literal["function", "classmethod", "method"],
+    indent: int = 0,
+) -> typing.Iterable[cst.FunctionDef]:
+    # Don't print overloads if just one!
+    if len(overloads) > 1:
+        for overload in overloads:
+            yield overload.function_def(name, type, indent=indent, overload=True)
+    yield fn.function_def(name, type, indent=indent)
 
 
 class Signature(BaseModel):
@@ -234,13 +340,15 @@ class Signature(BaseModel):
     pos_only_required: typing.Dict[str, Type] = pydantic.Field(default_factory=dict)
     pos_only_optional: typing.Dict[str, Type] = pydantic.Field(default_factory=dict)
     # If there are any pos_only_optional, then there cannot be any required pos_or_kw
-    pos_only_optional_ordering: PartialKeyOrdering = pydantic.Field(default_factory=set)
+    pos_only_optional_ordering: PartialKeyOrdering = pydantic.Field(
+        default_factory=list
+    )
 
     pos_or_kw_required: typing.Dict[str, Type] = pydantic.Field(default_factory=dict)
     pos_or_kw_optional: typing.Dict[str, Type] = pydantic.Field(default_factory=dict)
     # Partial ordering of args, (pred, suc) pairs
     pos_or_kw_optional_ordering: PartialKeyOrdering = pydantic.Field(
-        default_factory=set
+        default_factory=list
     )
     # Variable args are allowed if it this is not none
     var_pos: typing.Optional[typing.Tuple[str, Type]] = None
@@ -291,14 +399,20 @@ class Signature(BaseModel):
         name: str,
         type: typing.Literal["function", "classmethod", "method"],
         indent=0,
+        overload=False,
     ) -> cst.FunctionDef:
+        decorators: typing.List[cst.Decorator] = []
+        if overload:
+            decorators.append(cst.Decorator(cst.Name("overload")))
+        if type == "classmethod":
+            decorators.append(cst.Decorator(cst.Name("classmethod")))
         return cst.FunctionDef(
             cst.Name(name),
             self.parameters(type),
             cst.IndentedBlock(
                 [cst.SimpleStatementLine([s]) for s in self.body(indent)]
             ),
-            [cst.Decorator(cst.Name("classmethod"))] if type == "classmethod" else [],
+            decorators,
         )
 
     def body(self, indent: int) -> typing.Iterable[cst.BaseSmallStatement]:
@@ -412,6 +526,17 @@ class Signature(BaseModel):
             ),
         )
 
+    def content_equal(self, other: Signature) -> bool:
+        """
+        Returns true if all fields besides metadata are equal
+        """
+        for field in self.__fields__.keys():
+            if field == "metadata":
+                continue
+            if getattr(self, field) != getattr(other, field):
+                return False
+        return True
+
     def __ior__(self, other: Signature) -> Signature:
         self._copy_pos_only(other)
         self._copy_pos_or_kw(other)
@@ -438,23 +563,25 @@ class Signature(BaseModel):
         )
         self.pos_only_required = pos_only_required
 
-        addititional_ordering: PartialKeyOrdering = set()
+        addititional_ordering: PartialKeyOrdering = []
         # also add to ordering that new optional keys must come before old ones, because
         # they used to be required
         if self_new_pos_only_optional and self.pos_only_optional:
-            addititional_ordering.add(
+            add_list(
+                addititional_ordering,
                 (
                     # last of required is before first of optional
                     next(iter(reversed(self_new_pos_only_optional.keys()))),
                     next(iter(self.pos_only_optional.keys())),
-                )
+                ),
             )
         if other_new_pos_only_optional and other.pos_only_optional:
-            addititional_ordering.add(
+            add_list(
+                addititional_ordering,
                 (
                     next(iter(reversed(other_new_pos_only_optional.keys()))),
                     next(iter(other.pos_only_optional.keys())),
-                )
+                ),
             )
         update_unify(
             self.pos_only_optional,
@@ -462,8 +589,8 @@ class Signature(BaseModel):
             other.pos_only_optional,
             other_new_pos_only_optional,
         )
-
-        self.pos_only_optional_ordering.update(
+        update_list(
+            self.pos_only_optional_ordering,
             other.pos_only_optional_ordering,
             partial_key_ordering(self_new_pos_only_optional),
             partial_key_ordering(other_new_pos_only_optional),
@@ -499,7 +626,8 @@ class Signature(BaseModel):
             self_new_optional,
             other.pos_or_kw_optional,
         )
-        self.pos_or_kw_optional_ordering.update(
+        update_list(
+            self.pos_or_kw_optional_ordering,
             other.pos_or_kw_optional_ordering,
             partial_key_ordering(self_new_optional),
             partial_key_ordering(other_new_optional),
@@ -562,16 +690,16 @@ Module.update_forward_refs()
 
 
 def metadata_lines(m: Metadata) -> typing.Iterable[str]:
-    for k, v in m.items():
+    for k, v in sort_items(m):
         yield f"{k}: {v}"
 
 
 def partial_key_ordering(d: typing.Dict[str, Type]) -> PartialKeyOrdering:
     prev_key = None
-    pairs: PartialKeyOrdering = set()
+    pairs: PartialKeyOrdering = []
     for key in d.keys():
         if prev_key is not None:
-            pairs.add((prev_key, key))
+            add_list(pairs, (prev_key, key))
         prev_key = key
     return pairs
 
@@ -582,7 +710,7 @@ def possibly_order_dict(
     """
     Resort dict by topographical sorting of order
     """
-    return {k: d[k] for k in networkx.topological_sort(networkx.DiGraph(list(order)))}
+    return {k: d[k] for k in networkx.topological_sort(networkx.DiGraph(order))} or d
 
 
 def unify_named_types(
@@ -692,7 +820,12 @@ def merge_property_into_method(
 
 
 def merge_method_class(l: Class, r: Signature) -> Class:
-    l |= Class(constructor=r)
+    l.ior_constructor(r)
+    return l
+
+
+def merge_method_overloads_class(l: Class, r: typing.List[Signature]) -> Class:
+    merge_overloads(l.constructor_overloads, r)
     return l
 
 
@@ -705,3 +838,40 @@ def merge_methods_properties(
 
 update_metadata_and_types = functools.partial(update, f=merge_methods_properties)
 
+
+def merge_overloads(
+    old: typing.List[Signature], new: typing.List[Signature]
+) -> typing.List[Signature]:
+    """
+    Merges the two lists of overloads, updating the old list. Any signatures that match, we take the union of their metadata.
+    """
+    for new_sig in new:
+        # Iterate through all the old signatures, if we find one which matches, update that and break
+        for old_sig in old:
+            if new_sig.content_equal(old_sig):
+                update_add(old_sig.metadata, new_sig.metadata)
+                break
+        # Otherwise, we didn't find one, so add the new one to the old
+        else:
+            old.append(new_sig)
+    return old
+
+
+update_overloads = functools.partial(update, f=merge_overloads)
+
+
+T = typing.TypeVar("T")
+
+# Set theoretic functions on lists
+# Don't use sets because we want to preserve insertion order for determinism
+
+
+def add_list(l: typing.List[T], a: T) -> None:
+    if a not in l:
+        l.append(a)
+
+
+def update_list(l: typing.List[T], *others: typing.Iterable[T]) -> None:
+    for other in others:
+        for x in other:
+            add_list(l, x)
